@@ -48,6 +48,7 @@
 #include "net/npchandler.h"
 #include "net/playerhandler.h"
 
+#include "resources/avatardb.h"
 #include "resources/emotedb.h"
 #include "resources/iteminfo.h"
 #include "resources/monsterdb.h"
@@ -56,6 +57,7 @@
 #include "resources/resourcemanager.h"
 
 #include "gui/widgets/langtab.h"
+#include "gui/widgets/skillinfo.h"
 
 #include "utils/gettext.h"
 
@@ -251,6 +253,12 @@ void Being::setSubtype(const uint16_t subtype)
             mYDiff = mInfo->getSortOffsetY();
         }
     }
+    else if (mType == AVATAR)
+    {
+        mInfo = AvatarDB::get(mSubType);
+        if (mInfo)
+            setupSpriteDisplay(mInfo->getDisplay(), false);
+    }
     else if (mType == PET)
     {
         mInfo = PETDB::get(mId);
