@@ -77,6 +77,7 @@
 #include "net/npchandler.h"
 #include "net/partyhandler.h"
 
+#include "resources/avatardb.h"
 #include "resources/chardb.h"
 #include "resources/colordb.h"
 #include "resources/emotedb.h"
@@ -142,12 +143,13 @@ std::string errorMessage;
 ErrorListener errorListener;
 LoginData loginData;
 
-Configuration config;             /**< XML file configuration reader */
-Configuration serverConfig;       /**< XML file server configuration reader */
-Configuration branding;           /**< XML branding information reader */
-Configuration paths;              /**< XML default paths information reader */
-Logger *logger = nullptr;         /**< Log object */
-ChatLogger *chatLogger = nullptr; /**< Chat log object */
+Configuration config;              // XML file configuration reader
+Configuration serverConfig;        // XML file server configuration reader
+Configuration features;            // XML file features
+Configuration branding;            // XML branding information reader
+Configuration paths;               // XML default paths information reader
+Logger *logger = nullptr;          // Log object
+ChatLogger *chatLogger = nullptr;  // Chat log object
 KeyboardConfig keyboard;
 UserPalette *userPalette = nullptr;
 Graphics *mainGraphics = nullptr;
@@ -286,18 +288,20 @@ Client::Client(const Options &options) :
     mIcon(nullptr),
     mLogicCounterId(nullptr),
     mSecondsCounterId(nullptr),
+    mCaption(),
+    mFpsManager(),
+    mSkin(nullptr),
+    mButtonPadding(1),
+    mButtonSpacing(3),
+    mKeyboardHeight(0),
+    mOldUpdates(),
+    mGuiAlpha(1.0f),
     mLimitFps(false),
     mConfigAutoSaved(false),
     mIsMinimized(false),
     mInputFocused(true),
     mMouseFocused(true),
-    mGuiAlpha(1.0f),
-    mCaption(),
-    mNewMessageFlag(false),
-    mFpsManager(),
-    mSkin(nullptr),
-    mButtonPadding(1),
-    mButtonSpacing(3)
+    mNewMessageFlag(false)
 {
     mInstance = this;
 
@@ -342,6 +346,7 @@ void Client::gameInit()
         logger->setLogFile(mLocalDataDir + "/manaplus.log");
 
     initConfiguration();
+    initFeatures();
     logger->log("init 4");
     logger->setDebugLog(config.getBoolValue("debugLog"));
 
@@ -759,6 +764,7 @@ void Client::gameClear()
     ItemDB::unload();
     MonsterDB::unload();
     NPCDB::unload();
+    AvatarDB::unload();
     PaletteDB::unload();
     PETDB::unload();
     StatusEffect::unload();
@@ -1071,6 +1077,7 @@ int Client::gameExec()
         {
             mServerName = mCurrentServer.hostname;
             initServerConfig(mCurrentServer.hostname);
+            initFeatures();
             loginData.registerUrl = mCurrentServer.registerUrl;
             if (!mCurrentServer.onlineListUrl.empty())
                 mOnlineListUrl = mCurrentServer.onlineListUrl;
@@ -1199,8 +1206,36 @@ int Client::gameExec()
             switch (mState)
             {
                 case STATE_CHOOSE_SERVER:
+                {
                     BLOCK_START("Client::gameExec STATE_CHOOSE_SERVER")
                     logger->log1("State: CHOOSE SERVER");
+                    ResourceManager *const resman
+                        = ResourceManager::getInstance();
+                    if (mOptions.dataPath.empty())
+                    {
+                        // Add customdata directory
+                        resman->searchAndRemoveArchives(
+                            "customdata/",
+                            "zip");
+                    }
+
+                    if (!mOldUpdates.empty())
+                    {
+                        UpdaterWindow::unloadUpdates(mOldUpdates);
+                        mOldUpdates.clear();
+                    }
+
+                    if (!mOptions.skipUpdate)
+                    {
+                        resman->searchAndRemoveArchives(
+                            mUpdatesDir + "/local/",
+                            "zip");
+
+                        resman->removeFromSearchPath(mLocalDataDir
+                            + dirSeparator + mUpdatesDir + "/local/");
+                    }
+
+                    resman->clearCache();
 
                     loginData.clearUpdateHost();
                     serverVersion = 0;
@@ -1229,6 +1264,7 @@ int Client::gameExec()
                     }
                     BLOCK_END("Client::gameExec STATE_CHOOSE_SERVER")
                     break;
+                }
 
                 case STATE_CONNECT_SERVER:
                     BLOCK_START("Client::gameExec STATE_CONNECT_SERVER")
@@ -1324,6 +1360,7 @@ int Client::gameExec()
 
                 case STATE_UPDATE:
                     BLOCK_START("Client::gameExec STATE_UPDATE")
+                    logger->log1("State: UPDATE");
                     // Determine which source to use for the update host
                     if (!mOptions.updateHost.empty())
                         mUpdateHost = mOptions.updateHost;
@@ -1331,22 +1368,29 @@ int Client::gameExec()
                         mUpdateHost = loginData.updateHost;
                     initUpdatesDir();
 
+                    if (!mOldUpdates.empty())
+                        UpdaterWindow::unloadUpdates(mOldUpdates);
+
                     if (mOptions.skipUpdate)
                     {
                         mState = STATE_LOAD_DATA;
+                        mOldUpdates = "";
                     }
                     else if (loginData.updateType & LoginData::Upd_Skip)
                     {
-                        UpdaterWindow::loadLocalUpdates(mLocalDataDir
-                            + dirSeparator + mUpdatesDir);
+                        mOldUpdates = mLocalDataDir
+                            + dirSeparator + mUpdatesDir;
+                        UpdaterWindow::loadLocalUpdates(mOldUpdates);
                         mState = STATE_LOAD_DATA;
                     }
                     else
                     {
-                        logger->log1("State: UPDATE");
+                        mOldUpdates = mLocalDataDir
+                            + dirSeparator + mUpdatesDir;
                         mCurrentDialog = new UpdaterWindow(mUpdateHost,
-                            mLocalDataDir + dirSeparator + mUpdatesDir,
-                            mOptions.dataPath.empty(), loginData.updateType);
+                            mOldUpdates,
+                            mOptions.dataPath.empty(),
+                            loginData.updateType);
                     }
                     BLOCK_END("Client::gameExec STATE_UPDATE")
                     break;
@@ -1408,6 +1452,7 @@ int Client::gameExec()
 #ifdef MANASERV_SUPPORT
                     SpecialDB::load();
 #endif
+                    AvatarDB::load();
                     NPCDB::load();
                     PETDB::load();
                     EmoteDB::load();
@@ -2010,9 +2055,12 @@ void Client::initServerConfig(std::string serverName)
     dropShortcut = new DropShortcut;
 }
 
-/**
- * Initialize configuration.
- */
+void Client::initFeatures() const
+{
+    features.init("features.xml", true);
+    paths.setDefaultValues(getFeaturesDefaults());
+}
+
 void Client::initConfiguration() const
 {
 #ifdef DEBUG_CONFIG
@@ -2928,7 +2976,7 @@ void Client::windowRemoved(const Window *const window)
 
 void Client::updateScreenKeyboard(int height A_UNUSED)
 {
-//    logger->log("keyboard height: %d", height);
+    instance()->mKeyboardHeight = height;
 }
 
 void Client::checkConfigVersion()
