@@ -291,6 +291,9 @@ public:
                        const bool always = false)
     { instance()->resizeVideo(width, height, always); }
 
+    static bool isKeyboardVisible()
+    { return instance()->mKeyboardHeight > 1; }
+
     static void setGuiAlpha(const float n);
 
     static float getGuiAlpha() A_WARN_UNUSED;
@@ -356,6 +359,8 @@ private:
 
     void initServerConfig(std::string serverName);
 
+    void initFeatures() const;
+
     void accountLogin(LoginData *const data) const;
 
     void storeSafeParameters() const;
@@ -410,18 +415,20 @@ private:
     SDL_TimerID mLogicCounterId;
     SDL_TimerID mSecondsCounterId;
 
+    std::string mCaption;
+    FPSmanager mFpsManager;
+    Skin *mSkin;
+    int mButtonPadding;
+    int mButtonSpacing;
+    int mKeyboardHeight;
+    std::string mOldUpdates;
+    float mGuiAlpha;
     bool mLimitFps;
     bool mConfigAutoSaved;
     bool mIsMinimized;
     bool mInputFocused;
     bool mMouseFocused;
-    float mGuiAlpha;
-    std::string mCaption;
     bool mNewMessageFlag;
-    FPSmanager mFpsManager;
-    Skin *mSkin;
-    int mButtonPadding;
-    int mButtonSpacing;
 };
 
 #endif  // CLIENT_H
