@@ -359,10 +359,7 @@ impHandler0(clear)
 
 impHandler0(cleanGraphics)
 {
-    ResourceManager *const resman = ResourceManager::getInstance();
-    resman->cleanProtected();
-    while (resman->cleanOrphans(true))
-        continue;
+    ResourceManager::getInstance()->clearCache();
 
     if (debugChatTab)
     {
@@ -1147,6 +1144,54 @@ impHandler1(execute)
     execFile(name, name, params, "");
 }
 
+impHandler2(enableHighlight)
+{
+    if (tab)
+    {
+        tab->setAllowHighlight(true);
+        if (chatWindow)
+            chatWindow->saveState();
+    }
+}
+
+impHandler2(disableHighlight)
+{
+    if (tab)
+    {
+        tab->setAllowHighlight(false);
+        if (chatWindow)
+            chatWindow->saveState();
+    }
+}
+
+impHandler2(dontRemoveName)
+{
+    tab->setRemoveNames(false);
+    if (chatWindow)
+        chatWindow->saveState();
+}
+
+impHandler2(removeName)
+{
+    tab->setRemoveNames(true);
+    if (chatWindow)
+        chatWindow->saveState();
+}
+
+impHandler2(disableAway)
+{
+    tab->setNoAway(true);
+    if (chatWindow)
+        chatWindow->saveState();
+}
+
+impHandler2(enableAway)
+{
+    tab->setNoAway(false);
+    if (chatWindow)
+        chatWindow->saveState();
+}
+
 impHandler0(testsdlfont)
 {
 #if defined USE_OPENGL && defined DEBUG_SDLFONT
