@@ -315,6 +315,18 @@ void ConfigurationObject::clear()
     mContainerOptions.clear();
 }
 
+ConfigurationObject::ConfigurationObject() :
+    mOptions(),
+#ifdef DEBUG_CONFIG
+    mContainerOptions(),
+    mLogKeys(false),
+    mIsMain(false)
+#else
+    mContainerOptions()
+#endif
+{
+}
+
 ConfigurationObject::~ConfigurationObject()
 {
     clear();
@@ -322,9 +334,11 @@ ConfigurationObject::~ConfigurationObject()
 
 Configuration::Configuration() :
     ConfigurationObject(),
+    mListenerMap(),
     mConfigPath(),
     mDefaultsData(nullptr),
     mDirectory(),
+    mFilename(),
     mUseResManager(false)
 {
 #ifdef DEBUG_CONFIG
