@@ -356,6 +356,10 @@ class Graphics : public gcn::SDLGraphics
 #ifdef DEBUG_DRAW_CALLS
         virtual unsigned int getDrawCalls() const
         { return 0; }
+#endif
+#ifdef DEBUG_BIND_TEXTURE
+        virtual unsigned int getBinds() const
+        { return 0; }
 #endif
         int mWidth;
         int mHeight;
