@@ -60,11 +60,17 @@
 
 static const char *SORT_NAME_INVENTORY[6] =
 {
+    // TRANSLATORS: inventory sort mode
     N_("default"),
+    // TRANSLATORS: inventory sort mode
     N_("by name"),
+    // TRANSLATORS: inventory sort mode
     N_("by id"),
+    // TRANSLATORS: inventory sort mode
     N_("by weight"),
+    // TRANSLATORS: inventory sort mode
     N_("by amount"),
+    // TRANSLATORS: inventory sort mode
     N_("by type")
 };
 
@@ -74,13 +80,13 @@ public:
     virtual ~SortListModelInv()
     { }
 
-    virtual int getNumberOfElements()
+    virtual int getNumberOfElements() override
     { return 6; }
 
-    virtual std::string getElementAt(int i)
+    virtual std::string getElementAt(int i) override
     {
         if (i >= getNumberOfElements() || i < 0)
-            return _("???");
+            return "???";
 
         return gettext(SORT_NAME_INVENTORY[i]);
     }
@@ -127,6 +133,7 @@ InventoryWindow::InventoryWindow(Inventory *const inventory):
     }
     else
     {
+        // TRANSLATORS: inventory window name
         setCaption(_("Inventory"));
         setWindowName("Inventory");
     }
@@ -165,12 +172,15 @@ InventoryWindow::InventoryWindow(Inventory *const inventory):
 
     if (isMainInventory())
     {
-        std::string equip = _("Equip");
-        std::string use = _("Use");
-        std::string unequip = _("Unequip");
+        // TRANSLATORS: inventory button
+        const std::string equip = _("Equip");
+        // TRANSLATORS: inventory button
+        const std::string use = _("Use");
+        // TRANSLATORS: inventory button
+        const std::string unequip = _("Unequip");
 
         std::string longestUseString = getFont()->getWidth(equip) >
-                                       getFont()->getWidth(use) ? equip : use;
+            getFont()->getWidth(use) ? equip : use;
 
         if (getFont()->getWidth(longestUseString) <
             getFont()->getWidth(unequip))
@@ -179,10 +189,15 @@ InventoryWindow::InventoryWindow(Inventory *const inventory):
         }
 
         mUseButton = new Button(this, longestUseString, "use", this);
+        // TRANSLATORS: inventory button
         mDropButton = new Button(this, _("Drop..."), "drop", this);
+        // TRANSLATORS: inventory button
         mSplitButton = new Button(this, _("Split"), "split", this);
+        // TRANSLATORS: inventory button
         mOutfitButton = new Button(this, _("Outfits"), "outfit", this);
+        // TRANSLATORS: inventory button
         mShopButton = new Button(this, _("Shop"), "shop", this);
+        // TRANSLATORS: inventory button
         mEquipmentButton = new Button(this, _("Equipment"), "equipment", this);
         mWeightBar = new ProgressBar(this, 0.0f, 100, 0, Theme::PROG_WEIGHT);
 
@@ -205,8 +220,11 @@ InventoryWindow::InventoryWindow(Inventory *const inventory):
     }
     else
     {
+        // TRANSLATORS: storage button
         mStoreButton = new Button(this, _("Store"), "store", this);
+        // TRANSLATORS: storage button
         mRetrieveButton = new Button(this, _("Retrieve"), "retrieve", this);
+        // TRANSLATORS: storage button
         mInvCloseButton = new Button(this, _("Close"), "close", this);
 
         mSlotsBarCell = &place(0, 0, mSlotsBar, 6);
@@ -559,8 +577,8 @@ void InventoryWindow::valueChanged(const gcn::SelectionEvent &event A_UNUSED)
     if (mSplit && item && Net::getInventoryHandler()->
         canSplit(mItems->getSelectedItem()))
     {
-        ItemAmountWindow::showWindow(ItemAmountWindow::ItemSplit, this, item,
-                                     (item->getQuantity() - 1));
+        ItemAmountWindow::showWindow(ItemAmountWindow::ItemSplit,
+            this, item, item->getQuantity() - 1);
     }
     updateButtons(item);
 }
@@ -596,12 +614,19 @@ void InventoryWindow::updateButtons(const Item *item)
         if (item && item->isEquipment())
         {
             if (item->isEquipped())
+            {
+                // TRANSLATORS: inventory button
                 mUseButton->setCaption(_("Unequip"));
+            }
             else
+            {
+                // TRANSLATORS: inventory button
                 mUseButton->setCaption(_("Equip"));
+            }
         }
         else
         {
+            // TRANSLATORS: inventory button
             mUseButton->setCaption(_("Use"));
         }
     }
@@ -630,7 +655,8 @@ void InventoryWindow::close()
     }
     else
     {
-        Net::getInventoryHandler()->closeStorage(Inventory::STORAGE);
+        if (Net::getInventoryHandler())
+            Net::getInventoryHandler()->closeStorage(Inventory::STORAGE);
         scheduleDelete();
     }
 }
@@ -689,16 +715,22 @@ void InventoryWindow::updateDropButton()
 
     if (isStorageActive())
     {
+        // TRANSLATORS: inventory button
         mDropButton->setCaption(_("Store"));
     }
     else
     {
         const Item *const item = mItems->getSelectedItem();
-
         if (item && item->getQuantity() > 1)
+        {
+            // TRANSLATORS: inventory button
             mDropButton->setCaption(_("Drop..."));
+        }
         else
+        {
+            // TRANSLATORS: inventory button
             mDropButton->setCaption(_("Drop"));
+        }
     }
 }
 
