@@ -152,7 +152,7 @@ void SDLTextChunk::generate(TTF_Font *const font, const float alpha)
         || color.b != color2.b)
     {   // outlining
         SDL_Color sdlCol2;
-        SDL_Surface *background = imageHelper->create32BitSurface(
+        SDL_Surface *const background = imageHelper->create32BitSurface(
             width, height);
         if (!background)
         {
@@ -181,7 +181,6 @@ void SDLTextChunk::generate(TTF_Font *const font, const float alpha)
             static_cast<Uint16>(surface->w),
             static_cast<Uint16>(surface->h)
         };
-//                SDL_SetAlpha(surface2, 0, SDL_ALPHA_OPAQUE);
         MSDL_gfxBlitRGBA(surface2, nullptr, background, &rect);
         rect.x = -OUTLINE_SIZE;
         MSDL_gfxBlitRGBA(surface2, nullptr, background, &rect);
@@ -192,7 +191,6 @@ void SDLTextChunk::generate(TTF_Font *const font, const float alpha)
         MSDL_gfxBlitRGBA(surface2, nullptr, background, &rect);
         rect.x = 0;
         rect.y = 0;
-//                SDL_SetAlpha(surface, 0, SDL_ALPHA_OPAQUE);
         MSDL_gfxBlitRGBA(surface, nullptr, background, &rect);
         SDL_FreeSurface(surface);
         SDL_FreeSurface(surface2);
@@ -314,10 +312,13 @@ void TextChunkList::clear()
 
 static int fontCounter;
 
-SDLFont::SDLFont(std::string filename, const int size, const int style) :
+SDLFont::SDLFont(std::string filename,
+                 const int size,
+                 const int style) :
     mFont(nullptr),
     mCreateCounter(0),
     mDeleteCounter(0),
+    mOpengl(imageHelper->useOpenGL()),
     mCleanTime(cur_time + CLEAN_TIME)
 {
     const ResourceManager *const resman = ResourceManager::getInstance();
@@ -369,7 +370,9 @@ SDLFont::~SDLFont()
     }
 }
 
-void SDLFont::loadFont(std::string filename, const int size, const int style)
+void SDLFont::loadFont(std::string filename,
+                       const int size,
+                       const int style)
 {
     const ResourceManager *const resman = ResourceManager::getInstance();
 
@@ -421,7 +424,7 @@ void SDLFont::drawString(gcn::Graphics *const graphics,
         return;
 
     gcn::Color col = g->getColor();
-    gcn::Color col2 = g->getColor2();
+    const gcn::Color col2 = g->getColor2();
     const float alpha = static_cast<float>(col.a) / 255.0f;
 
     /* The alpha value is ignored at string generation so avoid caching the
@@ -432,21 +435,55 @@ void SDLFont::drawString(gcn::Graphics *const graphics,
     const unsigned char chr = text[0];
     TextChunkList *const cache = &mCache[chr];
 
-    std::map<SDLTextChunkSmall, SDLTextChunk*> &search = cache->search;
-    std::map<SDLTextChunkSmall, SDLTextChunk*>::iterator i
-        = search.find(SDLTextChunkSmall(text, col, col2));
-    if (i != search.end())
+    if (!mOpengl)
     {
-        SDLTextChunk *const chunk2 = (*i).second;
-        cache->moveToFirst(chunk2);
-        Image *const image = chunk2->img;
-        if (image)
+        bool found(false);
+        SDLTextChunk chunk(text, col, col2);
+        SDLTextChunk *i1 = cache->start;
+        while (i1)
         {
-            image->setAlpha(alpha);
-            g->drawImage(image, x, y);
+            if (*i1 == chunk)
+            {
+                cache->moveToFirst(i1);
+                found = true;
+                break;
+            }
+            i1 = i1->next;
+        }
+
+        if (found)
+        {
+            Image *const image = cache->start->img;
+            if (image)
+            {
+                image->setAlpha(alpha);
+                g->drawImage(image, x, y);
+            }
+            BLOCK_END("SDLFont::drawString")
+            return;
         }
     }
     else
+    {
+        std::map<SDLTextChunkSmall, SDLTextChunk*> &search = cache->search;
+        std::map<SDLTextChunkSmall, SDLTextChunk*>::iterator i
+            = search.find(SDLTextChunkSmall(text, col, col2));
+        if (i != search.end())
+        {
+            SDLTextChunk *const chunk2 = (*i).second;
+
+            cache->moveToFirst(chunk2);
+            Image *const image = chunk2->img;
+            if (image)
+            {
+                image->setAlpha(alpha);
+                g->drawImage(image, x, y);
+            }
+            BLOCK_END("SDLFont::drawString")
+            return;
+        }
+    }
+//    else
     {
         if (cache->size >= CACHE_SIZE)
         {
@@ -506,37 +543,6 @@ int SDLFont::getWidth(const std::string &text) const
             return 0;
     }
 
-/*
-#ifdef DEBUG_FONT
-    int cnt = 0;
-#endif
-
-    SDLTextChunk *i = cache->start;
-    while (i)
-    {
-        if (i->text == text)
-        {
-            // Raise priority: move it to front
-            // Assumption is that TTF::draw will be called next
-            cache->moveToFirst(i);
-            const Image *const image = i->img;
-            if (image)
-                return image->getWidth();
-            else
-                return 0;
-        }
-        i = i->next;
-#ifdef DEBUG_FONT
-        cnt ++;
-#endif
-    }
-
-#ifdef DEBUG_FONT
-    logger->log(std::string("getWidth: ").append(text).append(
-        ", iterations: ").append(toString(cnt)));
-#endif
-*/
-
     // if string was not drawed
     int w, h;
     getSafeUtf8String(text, strBuf);
@@ -591,7 +597,7 @@ void SDLFont::doClean()
     }
 }
 
-TextChunkList *SDLFont::getCache()
+TextChunkList *SDLFont::getCache() const
 {
     return mCache;
 }
