@@ -27,8 +27,6 @@
 
 #include "gui/widgets/setupitem.h"
 
-#include <guichan/actionlistener.hpp>
-
 class Setup_Audio final : public SetupTabScroll
 {
     public:
@@ -38,7 +36,7 @@ class Setup_Audio final : public SetupTabScroll
 
         ~Setup_Audio();
 
-        void apply();
+        void apply() override;
 
     private:
         gcn::ListModel *mSoundModel;
