@@ -25,8 +25,6 @@
 
 #include "gui/widgets/setuptabscroll.h"
 
-#include <guichan/actionlistener.hpp>
-
 class IntTextField;
 class EditDialog;
 
@@ -37,9 +35,9 @@ class Setup_Chat final : public SetupTabScroll
 
         A_DELETE_COPY(Setup_Chat)
 
-        void apply();
+        void apply() override;
 
-        void externalUpdated();
+        void externalUpdated() override;
 };
 
 #endif
