@@ -24,7 +24,6 @@
 
 #include "gui/widgets/setuptab.h"
 
-#include <guichan/actionlistener.hpp>
 #include <guichan/selectionlistener.hpp>
 
 #include <string>
@@ -47,9 +46,9 @@ class Setup_Colors final : public SetupTab,
 
         ~Setup_Colors();
 
-        void apply();
+        void apply() override;
 
-        void cancel();
+        void cancel() override;
 
         void action(const gcn::ActionEvent &event) override;
 
