@@ -26,8 +26,6 @@
 
 #include "gui/widgets/setuptab.h"
 
-#include <guichan/actionlistener.hpp>
-
 #include <string>
 
 class Button;
@@ -53,9 +51,9 @@ class Setup_Input final : public SetupTab
          */
         ~Setup_Input();
 
-        void apply();
+        void apply() override;
 
-        void cancel();
+        void cancel() override;
 
         void action(const gcn::ActionEvent &event) override;
 
@@ -98,9 +96,7 @@ class Setup_Input final : public SetupTab
         Button *mDefaultButton;
         Button *mResetKeysButton;
         TabStrip *mTabs;
-
         bool mKeySetting; /**< flag to check if key being set. */
-
         int *mActionDataSize;
 };
 
