@@ -25,8 +25,6 @@
 
 #include "gui/widgets/setuptab.h"
 
-#include <guichan/actionlistener.hpp>
-
 class Button;
 class CheckBox;
 class DropDown;
@@ -42,9 +40,9 @@ class Setup_Joystick final : public SetupTab
 
         ~Setup_Joystick();
 
-        void apply();
+        void apply() override;
 
-        void cancel();
+        void cancel() override;
 
         void action(const gcn::ActionEvent &event) override;
 
