@@ -25,8 +25,6 @@
 
 #include "gui/widgets/setupitem.h"
 
-#include <guichan/actionlistener.hpp>
-
 class EditDialog;
 class NamesModel;
 class TextField;
@@ -39,8 +37,10 @@ class Setup_Other final : public SetupTabScroll
         A_DELETE_COPY(Setup_Other)
 
         ~Setup_Other();
-        void apply();
-        void externalUpdated();
+
+        void apply() override;
+
+        void externalUpdated() override;
 
     protected:
         NamesModel *mProxyTypeList;
