@@ -25,8 +25,6 @@
 
 #include "gui/widgets/setuptabscroll.h"
 
-#include <guichan/actionlistener.hpp>
-
 class EditDialog;
 class IntTextField;
 class NamesModel;
@@ -40,8 +38,6 @@ class Setup_Perfomance final : public SetupTabScroll
 
         ~Setup_Perfomance();
 
-        void apply();
-
     private:
         NamesModel *mTexturesList;
 };
