@@ -27,8 +27,6 @@
 
 #include "gui/widgets/setuptab.h"
 
-#include <guichan/actionlistener.hpp>
-
 class Button;
 class CheckBox;
 class DropDown;
@@ -53,9 +51,9 @@ public:
 
     virtual ~Setup_Relations();
 
-    void apply();
+    void apply() override;
 
-    void cancel();
+    void cancel() override;
 
     void reset();
 
@@ -65,7 +63,7 @@ public:
 
     virtual void updateAll();
 
-    virtual void externalUpdated();
+    virtual void externalUpdated() override;
 
 private:
     StaticTableModel *mPlayerTableTitleModel;
