@@ -72,6 +72,7 @@ const std::string ColorTypeNames[] =
     "ColorAttackRange",
     "ColorAttackRangeBorder",
     "ColorMonsterAttackRange",
+    "ColorFloorItemText",
     "ColorHomePlace",
     "ColorHomePlaceBorder",
     "ColorRoadPoint"
@@ -112,62 +113,108 @@ UserPalette::UserPalette():
     mColors[NPC] = ColorElem();
     mColors[MONSTER] = ColorElem();
 
+    // TRANSLATORS: palette color
     addColor(BEING, 0xffffff, STATIC, _("Being"));
-    addColor(FRIEND, 0xb0ffb0, STATIC, _("Friend Names"));
-    addColor(DISREGARDED, 0xa00000, STATIC, _("Disregarded Names"));
-    addColor(IGNORED, 0xff0000, STATIC, _("Ignored Names"));
-    addColor(ERASED, 0xff0000, STATIC, _("Erased Names"));
-    addColor(PC, 0xffffff, STATIC, _("Other Players' Names"));
-    addColor(SELF, 0xff8040, STATIC, _("Own Name"));
-    addColor(GM, 0x00ff00, STATIC, _("GM Names"));
+    // TRANSLATORS: palette color
+    addColor(FRIEND, 0xb0ffb0, STATIC, _("Friend names"));
+    // TRANSLATORS: palette color
+    addColor(DISREGARDED, 0xa00000, STATIC, _("Disregarded names"));
+    // TRANSLATORS: palette color
+    addColor(IGNORED, 0xff0000, STATIC, _("Ignored names"));
+    // TRANSLATORS: palette color
+    addColor(ERASED, 0xff0000, STATIC, _("Erased names"));
+    // TRANSLATORS: palette color
+    addColor(PC, 0xffffff, STATIC, _("Other players names"));
+    // TRANSLATORS: palette color
+    addColor(SELF, 0xff8040, STATIC, _("Own name"));
+    // TRANSLATORS: palette color
+    addColor(GM, 0x00ff00, STATIC, _("GM names"));
+    // TRANSLATORS: palette color
     addColor(NPC, 0xc8c8ff, STATIC, _("NPCs"));
+    // TRANSLATORS: palette color
     addColor(MONSTER, 0xff4040, STATIC, _("Monsters"));
+    // TRANSLATORS: palette color
     addColor(MONSTER_HP, 0x00ff00, STATIC, _("Monster HP bar"), 50);
     addColor(MONSTER_HP2, 0xff0000, STATIC,
+        // TRANSLATORS: palette color
         _("Monster HP bar (second color)"), 50);
-    addColor(PARTY, 0xff00d8, STATIC, _("Party Members"));
-    addColor(GUILD, 0xff00d8, STATIC, _("Guild Members"));
-    addColor(PARTICLE, 0xffffff, STATIC, _("Particle Effects"));
-    addColor(PICKUP_INFO, 0x28dc28, STATIC, _("Pickup Notification"));
-    addColor(EXP_INFO, 0xffff00, STATIC, _("Exp Notification"));
+    // TRANSLATORS: palette color
+    addColor(PARTY, 0xff00d8, STATIC, _("Party members"));
+    // TRANSLATORS: palette color
+    addColor(GUILD, 0xff00d8, STATIC, _("Guild members"));
+    // TRANSLATORS: palette color
+    addColor(PARTICLE, 0xffffff, STATIC, _("Particle effects"));
+    // TRANSLATORS: palette color
+    addColor(PICKUP_INFO, 0x28dc28, STATIC, _("Pickup notification"));
+    // TRANSLATORS: palette color
+    addColor(EXP_INFO, 0xffff00, STATIC, _("Exp notification"));
+    // TRANSLATORS: palette color
     addColor(PLAYER_HP, 0x00ff00, STATIC, _("Player HP bar"), 50);
+    // TRANSLATORS: palette color
     addColor(PLAYER_HP2, 0xff0000, STATIC,
+        // TRANSLATORS: palette color
         _("Player HP bar (second color)"), 50);
-    addColor(HIT_PLAYER_MONSTER, 0x0064ff, STATIC, _("Player Hits Monster"));
-    addColor(HIT_MONSTER_PLAYER, 0xff3232, STATIC, _("Monster Hits Player"));
+    // TRANSLATORS: palette color
+    addColor(HIT_PLAYER_MONSTER, 0x0064ff, STATIC, _("Player hits monster"));
+    // TRANSLATORS: palette color
+    addColor(HIT_MONSTER_PLAYER, 0xff3232, STATIC, _("Monster hits player"));
+    // TRANSLATORS: palette color
     addColor(HIT_PLAYER_PLAYER, 0xff5050, STATIC,
-             _("Other Player Hits Local Player"));
+       // TRANSLATORS: palette color
+       _("Other player hits local player"));
+    // TRANSLATORS: palette color
     addColor(HIT_CRITICAL, 0xff0000, RAINBOW, _("Critical Hit"));
+    // TRANSLATORS: palette color
     addColor(HIT_LOCAL_PLAYER_MONSTER, 0x00ff00, STATIC,
-             _("Local Player Hits Monster"));
+        // TRANSLATORS: palette color
+        _("Local player hits monster"));
     addColor(HIT_LOCAL_PLAYER_CRITICAL, 0xff0000, RAINBOW,
-             _("Local Player Critical Hit"));
+        // TRANSLATORS: palette color
+        _("Local player critical hit"));
     addColor(HIT_LOCAL_PLAYER_MISS, 0x00ffa6, STATIC,
-             _("Local Player Miss"));
+    // TRANSLATORS: palette color
+        _("Local player miss"));
+    // TRANSLATORS: palette color
     addColor(MISS, 0xffff00, STATIC, _("Misses"));
-    addColor(PORTAL_HIGHLIGHT, 0xC80000, STATIC, _("Portal Highlight"));
+    // TRANSLATORS: palette color
+    addColor(PORTAL_HIGHLIGHT, 0xC80000, STATIC, _("Portal highlight"));
     addColor(COLLISION_HIGHLIGHT, 0x0000C8, STATIC,
-             _("Default collision Highlight"), 64);
+        // TRANSLATORS: palette color
+        _("Default collision highlight"), 64);
     addColor(AIR_COLLISION_HIGHLIGHT, 0xe0e0ff, STATIC,
-             _("Air collision Highlight"), 64);
+        // TRANSLATORS: palette color
+        _("Air collision highlight"), 64);
     addColor(WATER_COLLISION_HIGHLIGHT, 0x2050e0, STATIC,
-             _("Water collision Highlight"), 64);
+        // TRANSLATORS: palette color
+        _("Water collision highlight"), 64);
     addColor(GROUNDTOP_COLLISION_HIGHLIGHT, 0xffff00, STATIC,
-             _("Special ground collision Highlight"), 20);
+        // TRANSLATORS: palette color
+        _("Special ground collision highlight"), 20);
     addColor(WALKABLE_HIGHLIGHT, 0x00D000, STATIC,
-             _("Walkable Highlight"), 255);
+        // TRANSLATORS: palette color
+        _("Walkable highlight"), 255);
     addColor(ATTACK_RANGE, 0xffffff, STATIC,
-             _("Local Player Attack Range"), 5);
+        // TRANSLATORS: palette color
+        _("Local player attack range"), 5);
     addColor(ATTACK_RANGE_BORDER, 0x0, STATIC,
-             _("Local Player Attack Range Border"), 76);
+        // TRANSLATORS: palette color
+        _("Local player attack range border"), 76);
     addColor(MONSTER_ATTACK_RANGE, 0xff0000, STATIC,
-             _("Monster Attack Range"), 20);
+        // TRANSLATORS: palette color
+        _("Monster attack range"), 20);
+
+    addColor(FLOOR_ITEM_TEXT, 0xffffff, STATIC,
+        // TRANSLATORS: palette color
+        _("Floor item amount color"), 100);
     addColor(HOME_PLACE, 0xffffff, STATIC,
-             _("Home Place"), 20);
+        // TRANSLATORS: palette color
+        _("Home place"), 20);
     addColor(HOME_PLACE_BORDER, 0xffff00, STATIC,
-             _("Home Place Border"), 200);
+        // TRANSLATORS: palette color
+        _("Home place border"), 200);
     addColor(ROAD_POINT, 0x000000, STATIC,
-             _("Road Point"), 100);
+        // TRANSLATORS: palette color
+        _("Road point"), 100);
     commit(true);
 }
 
