@@ -46,10 +46,11 @@
 
 SpellShortcutContainer::SpellShortcutContainer(const unsigned number) :
     ShortcutContainer(),
-    mSpellClicked(false),
     mSpellMoved(nullptr),
     mSpellPopup(new SpellPopup),
-    mNumber(number)
+    mNumber(number),
+    mForegroundColor2(getThemeColor(Theme::TEXT_OUTLINE)),
+    mSpellClicked(false)
 {
     addMouseListener(this);
     addWidgetListener(this);
@@ -88,6 +89,7 @@ void SpellShortcutContainer::setWidget2(const Widget2 *const widget)
 {
     Widget2::setWidget2(widget);
     mForegroundColor = getThemeColor(Theme::TEXT);
+    mForegroundColor2 = getThemeColor(Theme::TEXT_OUTLINE);
 }
 
 void SpellShortcutContainer::draw(gcn::Graphics *graphics)
@@ -107,7 +109,7 @@ void SpellShortcutContainer::draw(gcn::Graphics *graphics)
     gcn::Font *const font = getFont();
 
     const int selectedId = spellShortcut->getSelectedItem();
-    g->setColor(mForegroundColor);
+    g->setColorAll(mForegroundColor, mForegroundColor2);
     drawBackground(g);
 
     for (unsigned i = 0; i < mMaxItems; i++)
