@@ -42,6 +42,8 @@ TabbedArea::TabbedArea(const Widget2 *const widget) :
     mSelectedTab(nullptr),
     mTabContainer(new gcn::Container()),
     mWidgetContainer(new gcn::Container()),
+    mTabsToDelete(),
+    mTabs(),
     mOpaque(false),
     mTabsWidth(0),
     mVisibleTabsWidth(0),
@@ -65,7 +67,7 @@ TabbedArea::TabbedArea(const Widget2 *const widget) :
     mArrowButton[0] = new Button(this, "<", "shift_left", this);
     mArrowButton[1] = new Button(this, ">", "shift_right", this);
 
-    widgetResized(nullptr);
+    widgetResized(gcn::Event(nullptr));
 }
 
 TabbedArea::~TabbedArea()
@@ -329,7 +331,7 @@ void TabbedArea::setSelectedTab(Tab *tab)
     if (newTab)
         newTab->setCurrent();
 
-    widgetResized(nullptr);
+    widgetResized(gcn::Event(nullptr));
 }
 
 int TabbedArea::getSelectedTabIndex() const
@@ -379,7 +381,7 @@ void TabbedArea::widgetResized(const gcn::Event &event A_UNUSED)
         {
             if (mFollowDownScroll && height != 0)
             {
-                const gcn::Rectangle rect = w->getDimension();
+                const gcn::Rectangle &rect = w->getDimension();
                 if (rect.height != 0 && rect.height > height + 2)
                 {
                     if (scr->getVerticalScrollAmount()
