@@ -116,8 +116,7 @@ Window::Window(const std::string &caption, const bool modal,
             setPadding(mSkin->getPadding());
             if (getOptionBool("titlebarBold"))
                 mCaptionFont = reinterpret_cast<gcn::Font*>(boldFont);
-            setTitlePadding(mSkin->getTitlePadding());
-            setTitleBarHeight(getOption("titlebarHeight"));
+            mTitlePadding = mSkin->getTitlePadding();
             mGripPadding = getOption("resizePadding");
             mCaptionOffsetX = getOption("captionoffsetx");
             if (!mCaptionOffsetX)
@@ -131,6 +130,11 @@ Window::Window(const std::string &caption, const bool modal,
             {
                 mCaptionAlign = gcn::Graphics::LEFT;
             }
+            setTitleBarHeight(getOption("titlebarHeight"));
+            if (!mTitleBarHeight)
+                mTitleBarHeight = mCaptionFont->getHeight() + mPadding;
+
+            mTitleBarHeight += getOption("titlebarHeightRelative");
             setPalette(getOption("palette"));
             childPalette = getOption("childPalette");
         }
@@ -279,8 +283,7 @@ void Window::draw(gcn::Graphics *graphics)
     // Draw title
     if (mShowTitle)
     {
-        g->setColor(mForegroundColor);
-        g->setColor2(mForegroundColor2);
+        g->setColorAll(mForegroundColor, mForegroundColor2);
         int x;
         switch (static_cast<gcn::Graphics::Alignment>(mCaptionAlign))
         {
