@@ -69,6 +69,7 @@ namespace gcn
         mInput(nullptr),
         mFocusHandler(new FocusHandler),
         mTabbing(true),
+        mKeyListeners(),
         mShiftPressed(false),
         mMetaPressed(false),
         mControlPressed(false),
@@ -78,7 +79,8 @@ namespace gcn
         mLastMouseX(0),
         mLastMouseY(0),
         mClickCount(1),
-        mLastMouseDragButton(0)
+        mLastMouseDragButton(0),
+        mWidgetWithMouseQueue()
     {
     }
 
@@ -479,7 +481,7 @@ namespace gcn
     {
         Widget *const widget = getWidgetAt(x, y);
 
-        //+++ possible nullpointer
+        // +++ possible nullpointer
         if (mFocusHandler->getModalMouseInputFocused()
             && !widget->isModalMouseInputFocused())
         {
@@ -493,7 +495,7 @@ namespace gcn
     {
         Widget* widget = mFocusHandler->getFocused();
 
-        //+++ possible nullpointer
+        // +++ possible nullpointer
         while (widget->_getInternalFocusHandler()
                && widget->_getInternalFocusHandler()->getFocused())
         {
@@ -716,7 +718,7 @@ namespace gcn
     {
         BLOCK_START("Gui::handleModalMouseInputFocus")
         // Check if modal mouse input focus has been gained by a widget.
-        if ((mFocusHandler->getLastWidgetWithModalMouseInputFocus() 
+        if ((mFocusHandler->getLastWidgetWithModalMouseInputFocus()
             != mFocusHandler->getModalMouseInputFocused())
             && (!mFocusHandler->getLastWidgetWithModalMouseInputFocus()))
         {
@@ -739,7 +741,7 @@ namespace gcn
     {
         BLOCK_START("Gui::handleModalFocus")
         // Check if modal focus has been gained by a widget.
-        if ((mFocusHandler->getLastWidgetWithModalFocus() 
+        if ((mFocusHandler->getLastWidgetWithModalFocus()
             != mFocusHandler->getModalFocused())
             && (!mFocusHandler->getLastWidgetWithModalFocus()))
         {
@@ -827,4 +829,4 @@ namespace gcn
             parent = swap->getParent();
         }
     }
-}
+}  // namespace gcn
