@@ -25,7 +25,7 @@
 
 #include "actorspritelistener.h"
 #include "being.h"
-#include "listener.h"
+#include "depricatedlistener.h"
 #include "localconsts.h"
 
 #include "gui/userpalette.h"
@@ -41,7 +41,6 @@ class ImageSet;
 class Item;
 class Map;
 class OkDialog;
-struct SkillInfo;
 
 class AwayListener final : public gcn::ActionListener
 {
@@ -68,7 +67,7 @@ enum
  */
 class LocalPlayer final : public Being,
                           public ActorSpriteListener,
-                          public Listener
+                          public DepricatedListener
 {
     public:
         /**
