@@ -54,14 +54,15 @@ MobileOpenGLGraphics::MobileOpenGLGraphics():
     mAlpha(false),
     mTexture(false),
     mIsByteColor(false),
+    mByteColor(),
     mFloatColor(1.0f),
     mMaxVertices(500),
-#ifdef DEBUG_BIND_TEXTURE
     mColorAlpha(false),
-    mOldTextureId(0)
-#else
-    mColorAlpha(false)
+#ifdef DEBUG_BIND_TEXTURE
+    mOldTexture(),
+    mOldTextureId(0),
 #endif
+    mFbo()
 {
     mOpenGL = 3;
     mName = "mobile OpenGL";
@@ -281,7 +282,7 @@ bool MobileOpenGLGraphics::drawRescaledImage(const Image *const image,
     drawRescaledQuad(image, srcX, srcY, dstX, dstY, width, height,
                      desiredWidth, desiredHeight);
 
-    if (smooth) // A basic smooth effect...
+    if (smooth)  // A basic smooth effect...
     {
         setColorAlpha(0.2f);
         drawRescaledQuad(image, srcX, srcY, dstX - 1, dstY - 1, width, height,
@@ -347,22 +348,22 @@ void MobileOpenGLGraphics::drawImagePattern(const Image *const image,
 
                 const float texX2 = static_cast<float>(srcX + width) / tw;
 
-                mFloatTexArray[vp + 0] = texX1;     //1
+                mFloatTexArray[vp + 0] = texX1;     // 1
                 mFloatTexArray[vp + 1] = texY1;
 
-                mFloatTexArray[vp + 2] = texX2;     //2
+                mFloatTexArray[vp + 2] = texX2;     // 2
                 mFloatTexArray[vp + 3] = texY1;
 
-                mFloatTexArray[vp + 4] = texX2;     //3
+                mFloatTexArray[vp + 4] = texX2;     // 3
                 mFloatTexArray[vp + 5] = texY2;
 
-                mFloatTexArray[vp + 6] = texX1;     //1
+                mFloatTexArray[vp + 6] = texX1;     // 1
                 mFloatTexArray[vp + 7] = texY1;
 
-                mFloatTexArray[vp + 8] = texX1;     //4
+                mFloatTexArray[vp + 8] = texX1;     // 4
                 mFloatTexArray[vp + 9] = texY2;
 
-                mFloatTexArray[vp + 10] = texX2;    //3
+                mFloatTexArray[vp + 10] = texX2;    // 3
                 mFloatTexArray[vp + 11] = texY2;
 
                 mShortVertArray[vp + 0] = static_cast<GLshort>(dstX);
@@ -828,7 +829,7 @@ void MobileOpenGLGraphics::updateScreen()
 #endif
     SDL_GL_SwapBuffers();
 // may be need clear?
-//    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
+//  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
     BLOCK_END("Graphics::updateScreen")
 }
 
@@ -1136,7 +1137,7 @@ bool MobileOpenGLGraphics::drawNet(const int x1, const int y1,
     const GLshort ys1 = static_cast<GLshort>(y1);
     const GLshort ys2 = static_cast<GLshort>(y2);
 
-    for (short y = y1; y < y2; y += height)
+    for (int16_t y = y1; y < y2; y += height)
     {
         mShortVertArray[vp + 0] = xs1;
         mShortVertArray[vp + 1] = y;
@@ -1152,7 +1153,7 @@ bool MobileOpenGLGraphics::drawNet(const int x1, const int y1,
         }
     }
 
-    for (short x = x1; x < x2; x += width)
+    for (int16_t x = x1; x < x2; x += width)
     {
         mShortVertArray[vp + 0] = x;
         mShortVertArray[vp + 1] = ys1;
@@ -1285,4 +1286,4 @@ void MobileOpenGLGraphics::debugBindTexture(const Image *const image A_UNUSED)
 }
 #endif
 
-#endif // USE_OPENGL
+#endif  // USE_OPENGL
