@@ -19,7 +19,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <wchar.h>
-#include <string.h>
 #include <ctype.h>
 
 #include <stdint.h>
@@ -36,7 +35,8 @@
 #include "debug.h"
 
 MumbleManager::MumbleManager() :
-    mLinkedMem(nullptr)
+    mLinkedMem(nullptr),
+    mLinkedMemCache()
 {
     mMapBase[0] = mMapBase[1] = mMapBase[2] = 0.;
     init();
@@ -98,8 +98,8 @@ void MumbleManager::init()
         return;
     }
 
-    mLinkedMem = (LinkedMem *) MapViewOfFile(hMapObject,
-        FILE_MAP_ALL_ACCESS, 0, 0, sizeof(LinkedMem));
+    mLinkedMem = reinterpret_cast<LinkedMem *>(MapViewOfFile(hMapObject,
+        FILE_MAP_ALL_ACCESS, 0, 0, sizeof(LinkedMem)));
 
     if (!mLinkedMem)
     {
@@ -111,7 +111,7 @@ void MumbleManager::init()
 #elif defined BSD4_4
 #else
     char memName[256];
-    snprintf(memName, 256, "/MumbleLink.%u", getuid());
+    snprintf(memName, sizeof(memName), "/MumbleLink.%u", getuid());
 
     const int shmfd = shm_open(memName, O_RDWR, S_IRUSR | S_IWUSR);
 
@@ -145,7 +145,7 @@ void MumbleManager::init()
     //
     // 1 unit = 1 meter
 
-    // Unit vector pointing out of the avatars eyes 
+    // Unit vector pointing out of the avatars eyes
     // (here Front looks into scene).
     /* no way to look "up", 2d */
     mLinkedMemCache.fAvatarFront[1] = 0.0f;
