@@ -34,7 +34,7 @@ namespace Ea
 class GuildTab : public ChatTab, public ConfigListener
 {
     public:
-        GuildTab(const Widget2 *const widget);
+        explicit GuildTab(const Widget2 *const widget);
 
         A_DELETE_COPY(GuildTab)
 
@@ -60,6 +60,6 @@ class GuildTab : public ChatTab, public ConfigListener
         void getAutoCompleteList(StringVect &names) const override;
 };
 
-} // namespace Ea
+}  // namespace Ea
 
-#endif // EA_GUILDTAB_H
+#endif  // EA_GUILDTAB_H
