@@ -34,13 +34,13 @@ namespace EAthena
 class GuildTab : public Ea::GuildTab
 {
     public:
-        GuildTab(const Widget2 *const widget);
+        explicit GuildTab(const Widget2 *const widget);
 
         A_DELETE_COPY(GuildTab)
 
         ~GuildTab();
 };
 
-} // namespace EAthena
+}  // namespace EAthena
 
-#endif // EATHENA_GUILDTAB_H
+#endif  // EATHENA_GUILDTAB_H
