@@ -34,13 +34,13 @@ namespace EAthena
 class PartyTab : public Ea::PartyTab
 {
     public:
-        PartyTab(const Widget2 *const widget);
+        explicit PartyTab(const Widget2 *const widget);
 
         A_DELETE_COPY(PartyTab)
 
         ~PartyTab();
 };
 
-} // namespace EAthena
+}  // namespace EAthena
 
-#endif // EATHENA_PARTYTAB_H
+#endif  // EATHENA_PARTYTAB_H
