@@ -103,7 +103,12 @@ class LoginHandler
 
         virtual void clearWorlds() = 0;
 
-        virtual ~LoginHandler ()
+        LoginHandler() :
+            mServer()
+        {
+        }
+
+        virtual ~LoginHandler()
         { }
 
     protected:
