@@ -46,7 +46,7 @@ class PlayerHandler
 
         virtual void decreaseAttribute(const int attr) const = 0;
 
-        virtual void increaseSkill(const unsigned short skillId) const = 0;
+        virtual void increaseSkill(const uint16_t skillId) const = 0;
 
         virtual void pickUp(const FloorItem *const floorItem) const = 0;
 
@@ -55,7 +55,7 @@ class PlayerHandler
         virtual void setDestination(const int x, const int y,
                                     const int direction) const = 0;
 
-        virtual void changeAction(const Being::Action action) const = 0;
+        virtual void changeAction(const Being::Action &action) const = 0;
 
         virtual void respawn() const = 0;
 
