@@ -25,6 +25,8 @@
 
 #include "utils/stringutils.h"
 
+#include <SDL_stdinc.h>
+
 #include <string>
 #include <vector>
 
@@ -47,17 +49,24 @@ public:
     Type type;
     std::string name;
     std::string hostname;
-    unsigned short port;
+    uint16_t port;
 
     std::string description;
     std::string registerUrl;
+    std::string onlineListUrl;
     VersionString version;
 
     bool save;
 
     ServerInfo() :
         type(TMWATHENA),
+        name(),
+        hostname(),
         port(6901),
+        description(),
+        registerUrl(),
+        onlineListUrl(),
+        version(),
         save(false)
     {
         version.first = 0;
@@ -70,6 +79,8 @@ public:
         port(info.port),
         description(info.description),
         registerUrl(info.registerUrl),
+        onlineListUrl(info.onlineListUrl),
+        version(),
         save(info.save)
     {
         version.first = info.version.first;
@@ -89,6 +100,7 @@ public:
         port = 0;
         description.clear();
         registerUrl.clear();
+        onlineListUrl.clear();
         version.first = 0;
         version.second.clear();
         save = false;
