@@ -34,13 +34,13 @@ namespace TmwAthena
 class GuildTab : public Ea::GuildTab
 {
     public:
-        GuildTab(const Widget2 *const widget);
+        explicit GuildTab(const Widget2 *const widget);
 
         A_DELETE_COPY(GuildTab)
 
         ~GuildTab();
 };
 
-} // namespace TmwAthena
+}  // namespace TmwAthena
 
-#endif // TA_GUILDTAB_H
+#endif  // TA_GUILDTAB_H
