@@ -34,13 +34,13 @@ namespace TmwAthena
 class PartyTab : public Ea::PartyTab
 {
     public:
-        PartyTab(const Widget2 *const widget);
+        explicit PartyTab(const Widget2 *const widget);
 
         A_DELETE_COPY(PartyTab)
 
         ~PartyTab();
 };
 
-} // namespace TmwAthena
+}  // namespace TmwAthena
 
-#endif // TA_PARTYTAB_H
+#endif  // TA_PARTYTAB_H
