@@ -47,13 +47,13 @@ class PlayerHandler final : public MessageHandler, public Ea::PlayerHandler
         void emote(const uint8_t emoteId) const override;
 
         void increaseAttribute(const int attr) const override;
-        void increaseSkill(const unsigned short skillId) const override;
+        void increaseSkill(const uint16_t skillId) const override;
 
         void pickUp(const FloorItem *const floorItem) const override;
         void setDirection(const unsigned char direction) const override;
         void setDestination(const int x, const int y,
                             const int direction) const override;
-        void changeAction(const Being::Action action) const override;
+        void changeAction(const Being::Action &action) const override;
         void processOnlineList(Net::MessageIn &msg) const;
         void requestOnlineList() const override;
         void updateStatus(const uint8_t status) const override;
@@ -61,6 +61,6 @@ class PlayerHandler final : public MessageHandler, public Ea::PlayerHandler
         void respawn() const override;
 };
 
-} // namespace TmwAthena
+}  // namespace TmwAthena
 
-#endif // NET_TA_PLAYERHANDLER_H
+#endif  // NET_TA_PLAYERHANDLER_H
