@@ -28,9 +28,18 @@
 
 struct WorldInfo final
 {
+    WorldInfo() :
+        address(0),
+        name(),
+        port(0),
+        online_users(0),
+        updateHost()
+    {
+    }
+
     int address;
     std::string name;
-    short port;
+    uint16_t port;
     int online_users;
     std::string updateHost;
 };
