@@ -33,8 +33,9 @@ class Resource;
 
 struct AtlasItem final
 {
-    AtlasItem(Image *image0) :
+    explicit AtlasItem(Image *const image0) :
         image(image0),
+        name(),
         x(0),
         y(0),
         width(image0->mBounds.w),
@@ -55,10 +56,12 @@ struct AtlasItem final
 struct TextureAtlas final
 {
     TextureAtlas() :
+        name(),
         atlasImage(nullptr),
         surface(nullptr),
         width(0),
-        height(0)
+        height(0),
+        items()
     {
     }
 
@@ -75,16 +78,17 @@ struct TextureAtlas final
 class AtlasResource final : public Resource
 {
     public:
-        AtlasResource()
+        AtlasResource() :
+            atlases()
         { }
 
         A_DELETE_COPY(AtlasResource)
 
         ~AtlasResource();
 
-        void incRef();
+        void incRef() override;
 
-        void decRef();
+        void decRef() override;
 
         std::vector<TextureAtlas*> atlases;
 };
@@ -100,9 +104,9 @@ class AtlasManager final
                                                const StringVect &files)
                                                A_WARN_UNUSED;
 
-        static void injectToResources(AtlasResource *resource);
+        static void injectToResources(AtlasResource *const resource);
 
-        static void moveToDeleted(AtlasResource *resource);
+        static void moveToDeleted(AtlasResource *const resource);
 
     private:
         static void loadImages(const StringVect &files,
@@ -112,10 +116,11 @@ class AtlasManager final
                                std::vector<TextureAtlas*> &atlases,
                                std::vector<Image*> &images, int size);
 
-        static SDL_Surface *createSDLAtlas(TextureAtlas *atlas) A_WARN_UNUSED;
+        static SDL_Surface *createSDLAtlas(TextureAtlas *const atlas)
+                                           A_WARN_UNUSED;
 
 
-        static void convertAtlas(TextureAtlas *atlas);
+        static void convertAtlas(TextureAtlas *const atlas);
 };
 
 #endif
