@@ -42,6 +42,8 @@ class Resource
          * Constructor
          */
         Resource() :
+            mIdPath(),
+            mSource(),
             mTimeStamp(0),
             mProtected(false),
 #ifdef DEBUG_DUMP_LEAKS
@@ -97,7 +99,7 @@ class Resource
         bool getDumped() const A_WARN_UNUSED
         { return mDumped; }
 
-        void setDumped(bool n)
+        void setDumped(const bool n)
         { mDumped = n; }
 #endif
 
