@@ -57,6 +57,14 @@ struct SpriteReference final
 
 struct SpriteDisplay final
 {
+    SpriteDisplay() :
+        image(),
+        floor(),
+        sprites(),
+        particles()
+    {
+    }
+
     std::string image;
     std::string floor;
     std::vector<SpriteReference*> sprites;
@@ -90,7 +98,7 @@ namespace SpriteAction
     static const std::string USE_ITEM = "item";
     static const std::string SPAWN = "spawn";
     static const std::string INVALID("");
-}
+}  // namespace SpriteAction
 
 enum SpriteDirection
 {
@@ -118,7 +126,8 @@ class SpriteDef final : public Resource
          * Loads a sprite definition file.
          */
         static SpriteDef *load(const std::string &file,
-                               const int variant, bool prot) A_WARN_UNUSED;
+                               const int variant,
+                               const bool prot) A_WARN_UNUSED;
 
         /**
          * Returns the specified action.
@@ -149,7 +158,10 @@ class SpriteDef final : public Resource
          * Constructor.
          */
         SpriteDef() :
-            Resource()
+            Resource(),
+            mImageSets(),
+            mActions(),
+            mProcessedFiles()
         { }
 
         /**
@@ -199,7 +211,8 @@ class SpriteDef final : public Resource
          * When there are no animations defined for the action "complete", its
          * animations become a copy of those of the action "with".
          */
-        void substituteAction(std::string complete, std::string with);
+        void substituteAction(const std::string &complete,
+                              const std::string &with);
 
         typedef std::map<std::string, ImageSet*> ImageSets;
         typedef ImageSets::iterator ImageSetIterator;
@@ -213,4 +226,4 @@ class SpriteDef final : public Resource
         std::set<std::string> mProcessedFiles;
 };
 
-#endif // SPRITEDEF_H
+#endif  // SPRITEDEF_H
